<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

use Conexa\Clippay\Repository\ClippayPaymentModel;
use Conexa\Clippay\Services\ClipService;

class ClippayFailModuleFrontController extends ModuleFrontController
{

    /**
     * @var CLipService
     */
    protected $service;

    /**
     * @var string
     */
    protected $clippay;

    /**
     * 
     * 
     */
    public function __construct()
    {
        parent::__construct();

        $this->service = new ClipService();
 
        $this->clippay = Tools::getValue('clippay'); 
    }

    /**
     * This class should be use by your Instant Payment
     */
    public function postProcess()
    {
        parent::initContent();
 
        $clippayPaymentId = ClippayPaymentModel::getPaymentClippay($this->clippay);

        if ($clippayPaymentId === false) {
            exit('fail');
        }

        $clippayPayment = new ClippayPaymentModel($clippayPaymentId);

        $checkout = $this->service->statusCheckout($this->paymentRequestId);

        $status = $checkout['status'];

        $url = Context::getContext()->link->getPageLink(
            'order',
            null,
            null,
            'step=3'
        );

        switch ($status) { 
            case 'CHECKOUT_CANCELLED':
                $this->errors[] = $this->l('The payment link was canceled due to excessive attempts (maximum 5)'); 
                break;
            case 'CHECKOUT_EXPIRED':
                $this->errors[] = $this->l('The payment link has expired. Payment link expires after 1 hour');
                break;
            default: 
                $this->errors[] = $this->l('An error occurred. Please contact the merchant to have more informations'); 
                break;
        }

        return $this->redirectWithNotifications($url);
    }

}
