<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

use Conexa\Clippay\Helpers\ClippayLog;
use Conexa\Clippay\Repository\ClippayPaymentModel;
use Conexa\Clippay\Services\ClipService;

class ClippayRedirectModuleFrontController extends ModuleFrontController
{
    /**
     * @var ClipService
     */
    protected $service;


    public function __construct()
    {
        parent::__construct();

        $this->service = new ClipService();
    }

    public function postProcess()
    {

        $cart = $this->context->cart;
        $customer = new Customer($cart->id_customer);
        $addressDelivery = new Address($cart->id_address_invoice);
        $total = (float) $cart->getOrderTotal(true, Cart::BOTH);
        
        $token = $cart->id . '_' . bin2hex(random_bytes(64));

        $shopName = Configuration::get('PS_SHOP_NAME'); 
        $invoice = new Address((int) $cart->id_address_invoice);
        $state = new State((int) $invoice->id_state);
        $country = new Country((int) $invoice->id_country);

        $params = [
            'amount' => $total,
            'currency' => 'MXN',
            'purchase_description' => $this->l('Payment in store ') . $shopName,
            'redirection_url' => [
                'success' => Context::getContext()->link->getModuleLink(
                    'clippay',
                    'success',
                    ['cart_id' => $cart->id, 'clippay' => $token]
                ),
                'error' => Context::getContext()->link->getModuleLink(
                    'clippay',
                    'fail',
                    ['cart_id' => $cart->id, 'clippay' => $token]
                ),
                 'default' => Context::getContext()->link->getModuleLink(
                    'clippay',
                    'success',
                    ['cart_id' => $cart->id, 'clippay' => $token]
                ), 
            ],
            'metadata' => [
                'me_reference_id' => str_replace([' ', '-', '_', '@', '*'], '', $shopName) . '_' . $cart->id,
                'customer_info' => [
                    'name' => $customer->firstname . ' ' . $customer->lastname,
                    'email' => $customer->email,
                    'phone' => str_replace('+', '', $addressDelivery->phone),
                ],
            ],
            'billing_address' => [
                  'zip_code' => $invoice->postcode,
                  'locality' => null,
                  'city' => $invoice->city,
                  'State' => $state->name,
                  'country' => $country->name,
                  'street' => $invoice->address1,
                  'outdoor_number' => null,
                  'interior_number' => null,
                  'reference' => $invoice->address2,
                  'between_streets' => null,
                  'floor' => null,
            ],
            'override_settings' => [
                'payment_method' => $this->paymentMethod(),
                'enable_tip' => false,
            ],
            'webhook_url' => Context::getContext()->link->getModuleLink(
                'clippay',
                'webhook',
                ['cart_id' => $cart->id, 'clippay' => $token]
            ),
        ];

        ClippayLog::info('STORE CLIP  '. $cart->id . '  ' . json_encode($params));
        $checkout = $this->service->checkout($params);
        ClippayPaymentModel::create($checkout, $cart->id, $token);
        $paymentRequestId = $checkout['payment_request_id'];
        Tools::redirect($checkout['payment_request_url']);
    }

    /**
     * 
     * */
    public function paymentMethod()
    {
        $stateId = Configuration::get('CLIPPAY_STATE');

        if ($stateId == 'Pay with card or cash') {
            return ['CARD', 'CASH'];
        }

        if ($stateId == 'Pay with card') {
            return ['CARD'];
        }

        if ($stateId == 'Pay with cash') {
           return ['CASH'];
        }

        return [];
    }
}
