<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

use Conexa\Clippay\Helpers\ClippayLog;
use Conexa\Clippay\Repository\ClippayPaymentModel;
use Conexa\Clippay\Services\ClipService;

class ClippaySuccessModuleFrontController extends ModuleFrontController
{

    /**
     * @var ClipService
     */
    protected $service;

    /**
     * @var string
     */
    protected $clippay;


    public function __construct()
    {
        parent::__construct();

        $this->service = new ClipService();

        $this->clippay = Tools::getValue('clippay');

    }

    /**
     * This class should be use by your Instant Payment
     */
    public function postProcess()
    {
        parent::initContent();

        /*
         * If the module is not active anymore, no need to process anything.
         */
        if ($this->module->active == false) {
            exit;
        }

        $clippayPaymentId = ClippayPaymentModel::getPaymentClippay($this->clippay);

        if ($clippayPaymentId === false) {
            exit(0);
        }

        $clippayPayment = new ClippayPaymentModel($clippayPaymentId);
        $response = $this->service->statusCheckout($clippayPayment->payment_request_id);

        ClippayLog::info('SUCCESS ' . $clippayPayment->id_cart . ' ' . json_encode($response)); 

        if ($clippayPayment->id_order) {
            $cart = new Cart((int) $clippayPayment->id_cart);
            $customer = new Customer((int) $cart->id_customer);
            $secure_key = $customer->secure_key;
            $module_id = $this->module->id;
            Tools::redirect(
                'index.php?controller=order-confirmation&id_cart=' . $clippayPayment->id_cart .
                '&id_module=' . $module_id .
                '&id_order=' . $clippayPayment->id_order .
                '&key=' . $secure_key
            );
        }

        if ($response['status'] == 'CHECKOUT_CANCELLED') {
            $url = Context::getContext()->link->getPageLink(
                'order',
                null,
                null,
                'step=3'
            );
            $this->errors[] = $this->l('The payment link was canceled due to excessive attempts (maximum 5)');

            return $this->redirectWithNotifications($url);
        }

        if ($response['status'] == 'CHECKOUT_EXPIRED') {
            $url = Context::getContext()->link->getPageLink(
                'order',
                null,
                null,
                'step=3'
            );
            $this->errors[] = $this->l('The payment link has expired. Payment link expires after 1 hour');

            return $this->redirectWithNotifications($url);
        }

        $this->setTemplate( 'module:clippay/views/templates/front/success.tpl');
    }

    /**
     * @return int
     */
    public function getOrderByCartId($id)
    {
        return version_compare(_PS_VERSION_, '1.7', '<') ? Order::getOrderByCartId((int) $id) : Order::getIdByCartId((int) $id);
    }
}
