<?php

/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace Conexa\Clippay\Helpers;

if (!defined('_PS_VERSION_')) {
    exit;
}

class ClippayLog
{
    /**
     * @param string|array $item
     *
     * @return void
     */
    public static function info($item)
    {
        self::write($item, 'info');
    }

    /**
     * @param string|array $item
     *
     * @return void
     */
    public static function error($item)
    {
        self::write($item, 'error');
    }

    /**
     * @param string|array $item
     *
     * @return void
     */
    public static function warning($item)
    {
        self::write($item, 'waring');
    }

    /**
     * Generate logs on mercadopago.log
     *
     * @param string $message
     * @param string $status
     *
     * @return void
     */
    public static function write($message, $status)
    {
        $isLogActive = (bool) \Configuration::get('CLIPPAY_LOG');

        if ($isLogActive) {
            if (is_array($message)) {
                $message = json_encode($message);
            }
            $date = date('Y-m-d H:i:s');
            $message = sprintf('[%s] [%s]: %s%s', $date, $status, $message, PHP_EOL);
            \PrestaShopLogger::addLog($message, 1, null, null, null, true);
        }
    }
}
