<?php

/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace Conexa\Clippay\Repository;

if (!defined('_PS_VERSION_')) {
    exit;
}

class ClippayPaymentModel extends \ObjectModel
{
    public $id;
    public $id_order;
    public $id_cart;
    public $payment_request_id;
    public $object_type;
    public $status;
    public $last_status_message;
    public $created_at;
    public $payment_request_url;
    public $modified_at;
    public $expired_at;
    public $clippay;
    public $transaction_id;

    public static $definition = [
        'table' => 'clippay_payment',
        'primary' => 'id_clippay',
        'multilang' => false,
        'fields' => [
            'id_order' => [
                'type' => self::TYPE_INT,
            ],

            'id_cart' => [
                'type' => self::TYPE_INT,
            ],

            'payment_request_id' => [
                'type' => self::TYPE_STRING,
            ],

            'object_type' => [
                'type' => self::TYPE_STRING,
            ],

            'status' => [
                'type' => self::TYPE_STRING,
            ],

            'last_status_message' => [
                'type' => self::TYPE_STRING,
            ],

            'created_at' => [
                'type' => self::TYPE_STRING,
            ],

            'payment_request_url' => [
                'type' => self::TYPE_STRING,
            ],

           'transaction_id' => [
                'type' => self::TYPE_STRING,
            ],

            'clippay' => [
                'type' => self::TYPE_STRING,
            ],

            'modified_at' => [
                'type' => self::TYPE_STRING,
            ],

            'expired_at' => [
                'type' => self::TYPE_STRING,
            ],
        ],
    ];

    public function __construct($id = null, $lang = null)
    {
        parent::__construct($id, $lang);
    }

    public static function create($arr, $cart_id, $clippay)
    {
        $item = new ClippayPaymentModel();
        $item->id_cart = $cart_id;
        $item->payment_request_id = $arr['payment_request_id'];
        $item->object_type = $arr['object_type'];
        $item->status = $arr['status'];
        $item->last_status_message = $arr['last_status_message'];
        $item->created_at = $arr['created_at'];
        $item->payment_request_url = $arr['payment_request_url'];
        $item->modified_at = $arr['modified_at'];
        $item->expired_at = $arr['expired_at'];
        $item->clippay = $clippay;
        $item->save();

        return $item;
    }

    /**
     * Get id cart is token is valid .
     *
     * @param int $token
     *
     * @return int
     */
    public static function isValid($payment_request_id, $cartId)
    {
        $sql = 'SELECT `id_cart` FROM `' . _DB_PREFIX_ . "clippay_payment` WHERE `payment_request_id` = '"
            . pSql($payment_request_id) . "' and `id_cart` = '" . pSql($cartId) . "'";
        $result = \Db::getInstance()->getValue($sql);

        return !empty($result) ? (int) $result : false;
    }

    public static function getPaymentClippay($clippay)
    {
        $sql = 'SELECT `id_clippay` FROM `' . _DB_PREFIX_ . "clippay_payment` WHERE `clippay` = '" . pSql($clippay) . "'";
        $result = \Db::getInstance()->getValue($sql);

        return !empty($result) ? (int) $result : false;
    }
}
