<?php

/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace Conexa\Clippay\Services;

if (!defined('_PS_VERSION_')) {
    exit;
}

use Conexa\Clippay\Helpers\ClippayLog;
use GuzzleHttp\Client;

class ClipService
{

    /**
     * @var Client
     */
    public $client;

    /**
     * @var string
     */
    // public $url = 'https://stageapi-gw.payclip.com/';
    
    public $url = 'https://api-gw.payclip.com/';

    /**
     * @param array params
     */
    public function __construct(array $argv = [])
    {
        $xApiKey = \Configuration::get('CLIPPAY_XAPIKEY', '');
        $headers = [
            'Accept' => 'application/json',
            'x-api-key' => 'Basic ' . $xApiKey,
        ];

        $this->client = new Client(
            array_merge(
                [
                    'headers' => $headers,
                ],
                $argv
            )
        );
    }

    /**
     * 
     * @param string $paymentRequestId
     */
    public function statusCheckout(string $paymentRequestId): array
    {
        $xApiKey = \Configuration::get('CLIPPAY_XAPIKEY', '');
        $url = $this->url . 'checkout/' . $paymentRequestId;
        $headers = [
            'Accept' => 'application/json',
            'Content-Type' => 'application/json',
            'x-api-key' => 'Basic ' . $xApiKey,
        ];
        $request = $this->client->get($url, ['headers' => $headers]);

        return json_decode($request->getBody(), true);
    }

    /**
     * 
     * @param array params
     */
    public function checkout(array $params)
    {
        $xApiKey = \Configuration::get('CLIPPAY_XAPIKEY', '');

        $url = $this->url . 'checkout';
        $headers = [
            'Accept' => 'application/json',
            'Content-Type' => 'application/json',
            'x-api-key' => 'Basic ' . $xApiKey,
        ];

        $request = $this->client->post($url, ['json' => $params, 'headers' => $headers]);

        return json_decode($request->getBody(), true);
    }


    /**
     * 
     * @return boolean 
     */
     public function credentialTest($from, $to, $xApiKey)
     {
         try {
             $params = [
                     'query' => [
                         'from' => $from,
                         'to' => $to,
                         'limit' => 20,
                     ],
                     'headers' => [
                         'Accept' => 'application/vnd.com.payclip.v2+json',
                         'Content-Type' => 'application/json',
                         'Authorization' => 'Basic ' . $xApiKey,
                     ],
             ];

             ClippayLog::info('TEST CREDENTIALS : ' . $this->url . 'payments ' . json_encode($params));

             $request = $this->client->get(
                 $this->url . 'payments',
                 $params
             );

             return true;
         } catch (Exception $e) {
             return false;
         }
     }
}
